@@ -1,7 +1,8 @@
+import contextlib
 import logging
 from functools import wraps
+from http import HTTPStatus
 from importlib import import_module
-from os import PathLike
 from pathlib import Path
 from re import match
 from typing import Any, Callable, Iterator, Optional
@@ -12,21 +13,32 @@ from dotify.decorators import cached_classproperty
 from dotify.dotify import Dotify
 from dotify.json_serializable import JsonSerializable, JsonSerializableMeta, logger
 
-logger = logging.getLogger(f"{logger.name}.{__name__}")
+logger = logging.getLogger("{0}.{1}".format(logger.name, __name__))
 
 
 class ModelMeta(JsonSerializableMeta):
-    """
+    """A class handling any model metadata.
+
     A metaclass serving as an abstraction layer over
     the `JsonSerializableMeta` metaclass, that automatically
     resolves the path to the `Model`'s JSON schema, as well as
     builds the `dependency` dictionary
     """
 
+    def __new__(cls, name, bases, attrs):
+        if "Json" in attrs:
+            attrs["Json"].schema = cls.dependency_path(name)
+
+            with contextlib.suppress(AttributeError):
+                attrs["Json"].dependencies = cls.dependencies_from(
+                    attrs["Json"].dependencies,
+                )
+
+        return super().__new__(cls, name, bases, attrs)
+
     @classmethod
     def dependency_basename(cls, model_name: str) -> str:
-        """Given the name of a `Model` resolve the basename of
-        the corresponding json schema
+        """Given the name of a `Model` resolve the basename of the corresponding json schema.
 
         Args:
             model_name (str): the name of a `Model`
@@ -34,12 +46,13 @@ class ModelMeta(JsonSerializableMeta):
         Returns:
             str: the basename of the file containing the json schema
         """
-        return f"{model_name.lower()}.json"
+        return "{0}.json".format(
+            model_name.lower(),
+        )
 
     @classmethod
-    def dependency_path(cls, model_name: str) -> PathLike:
-        """Given the name of a `Model` resolve the path to
-        the corresponding json schema
+    def dependency_path(cls, model_name: str) -> Path:
+        """Given the name of a `Model` resolve the path to the corresponding json schema.
 
         Args:
             model_name (str): the name of a `Model`
@@ -54,78 +67,57 @@ class ModelMeta(JsonSerializableMeta):
             / cls.dependency_basename(model_name)
         )
 
-    def __new__(cls, name, bases, attrs):
-        if "Json" in attrs:
-            attrs["Json"].schema = cls.dependency_path(name)
+    @classmethod
+    def dependencies_from(cls, dependency_names):
+        @cached_classproperty
+        def decorator(_):
+            model_types = []
+            for dependency_name in dependency_names:
+                module, _, model_type = dependency_name.rpartition(".")
 
-            if hasattr(attrs["Json"], "dependencies"):
-                dependency_names = attrs["Json"].dependencies
+                module = import_module(module)
+                model_type = getattr(module, model_type)
 
-                @cached_classproperty
-                def dependencies(_):
-                    types = []
-                    for dependency in dependency_names:
-                        module, _, type = dependency.rpartition(".")
+                model_types.append(model_type)
 
-                        module = import_module(module)
-                        type = getattr(module, type)
+            return {
+                cls.dependency_basename(model_type.__name__): model_type
+                for model_type in model_types
+            }
 
-                        types.append(type)
-
-                    return {
-                        cls.dependency_basename(dependency.__name__): dependency
-                        for dependency in types
-                    }
-
-                attrs["Json"].dependencies = dependencies
-
-        return super().__new__(cls, name, bases, attrs)
+        return decorator
 
 
 class Model(JsonSerializable, metaclass=ModelMeta):
-    """
-    The base class for every Spotify Web API entity
-    """
+    """The base class for every Spotify Web API entity."""
 
     class UnexpectedError(Exception):
-        """An exception indicating an unexpected error"""
-
-        pass
+        """An exception indicating an unexpected error."""
 
     class InvalidURL(Exception):
-        """
-        An exception thrown if the provided URL does not
-        correspond to a valid Spotify URL
-        """
-
-        pass
+        """An exception thrown if the provided URL does not correspond to a valid Spotify URL."""
 
     class NotFound(Exception):
-        """
-        An exception thrown if an operation fails to
-        retrieve the necessary information
-        """
-
-        pass
+        """An exception thrown if an operation fails to retrieve the necessary information."""
 
     def __repr__(self):
-        return f'<{self.__class__.__name__} "{str(self)}">'
+        return '<{0} "{1}">'.format(self.__class__.__name__, str(self))
 
     @cached_classproperty
     def context(cls) -> Optional[Dotify]:
-        """Get the current `Dotify` context
+        """Get the current `Dotify` context.
 
         Returns:
             Optional[Dotify]: the current `Dotify` context
         """
         try:
-            return Dotify.get_context()
+            return Dotify.context
         except TypeError:
             return None
 
     @classmethod
     def view_name(cls) -> str:
-        """Return the name of the Spotify view corresponding to the `Model`
+        """Return the name of the Spotify view corresponding to the `Model`.
 
         Returns:
             str: the name of the Spotify view
@@ -134,15 +126,14 @@ class Model(JsonSerializable, metaclass=ModelMeta):
 
     @classmethod
     def search(cls, query: str, limit: int = 1) -> Iterator["Model"]:
-        """Perform a Spotify search given a `query`
+        """Perform a Spotify search given a `query`.
 
         Args:
             query (str): the search `query`
             limit (int, optional): the number of items to return. Defaults to 1.
 
         Raises:
-            cls.NotFound: In case no results corresponding to the provided query
-            are found
+            cls.NotFound: In case no results corresponding to the provided query are found
 
         Returns:
             Iterator["Model"]: the `Model` instances corresponding to the query
@@ -158,8 +149,7 @@ class Model(JsonSerializable, metaclass=ModelMeta):
 
     @classmethod
     def validate_url(cls, method: Callable[..., Any]) -> Callable[..., Any]:
-        """A decorator that validates the supplied `URL`
-        before executing the decorated method
+        """A decorator that validates the supplied `URL` before executing the decorated method.
 
         Args:
             method (Callable[..., Any]): the method being decorated
@@ -172,23 +162,22 @@ class Model(JsonSerializable, metaclass=ModelMeta):
         """
 
         @wraps(method)
-        def wrapper(cls, url, *args, **kwargs):
-            view_name = cls.view_name()
-            pattern = f"https://open.spotify.com/{view_name}"
+        def wrapper(model_type, url, *args, **kwargs):
+            view_name = model_type.view_name()
+            pattern = "https://open.spotify.com/{0}".format(
+                view_name,
+            )
 
-            try:
-                assert match(pattern, url) is not None
-            except AssertionError:
-                raise cls.InvalidURL from None
+            if match(pattern, url) is None:
+                raise model_type.InvalidURL from None
 
-            return method(cls, url, *args, **kwargs)
+            return method(model_type, url, *args, **kwargs)
 
         return wrapper
 
     @classmethod
     def http_safeguard(cls, method: Callable[..., Any]) -> Callable[..., Any]:
-        """A decorator that converts http exceptions to `Model` level
-        exceptions
+        """A decorator that converts http exceptions to `Model` level exceptions.
 
         Args:
             method (Callable[..., Any]): the method being decorated
@@ -196,23 +185,22 @@ class Model(JsonSerializable, metaclass=ModelMeta):
         Raises:
             cls.NotFound: in case a `Spotipy` call returns an HTTP status of 404
             cls.InvalidURL: in case a `Spotipy` call returns an HTTP status of 400
-            cls.UnexpectedError: in case a `Spotipy` call returns any other HTTP status
-            indicating an error
+            cls.UnexpectedError: in case a `Spotipy` call returns an unexpected HTTP status
 
         Returns:
             Callable[..., Any]: the decorated method
         """
 
         @wraps(method)
-        def wrapper(cls, *args, **kwargs):
+        def wrapper(model_type, *args, **kwargs):
             try:
-                return method(cls, *args, **kwargs)
-            except SpotifyException as e:
-                if e.http_status == 404:
-                    raise cls.NotFound from None
-                elif e.http_status == 400:
-                    raise cls.InvalidURL from None
-                else:
-                    raise cls.UnexpectedError from None
+                return method(model_type, *args, **kwargs)
+            except SpotifyException as exception:
+                if exception.http_status == HTTPStatus.NOT_FOUND.value:
+                    raise model_type.NotFound from None
+                elif exception.http_status == HTTPStatus.BAD_REQUEST.value:
+                    raise model_type.InvalidURL from None
+
+                raise model_type.UnexpectedError from None
 
         return wrapper
